#!/bin/sh

set -euxo pipefail

sleep 2
if mongosh --eval "rs.conf()" >/dev/null 1>&1; then
  echo "ReplicaSet already configured, reconfiguring members' address"
  mongosh --eval << '_EOF'
    rs_conf = rs.conf();

{{- range $index, $instance := service "[[ .instance ]]-rs[[ .consul.suffix ]]" }}
    rs_conf.members[{{ index $instance.ServiceMeta "alloc" }}] =  {
          _id : {{ index $instance.ServiceMeta "alloc" }},
          host : "{{ index $instance.ServiceMeta "addr" }}:{{ $instance.Port }}"
    };
{{- end }}
    rs.reconfig(rs_conf, { "force": true });
_EOF

elif [ "${NOMAD_ALLOC_INDEX}" != "0" ]; then
  echo "Initialization will only run on NOMAD_ALLOC_INDEX 0, exiting"
  exit 0

else
  echo "Initializing replica set"
  sleep 60

  mongosh \
      --eval << '_EOF'
      rs_conf = {
        _id : "[[ .mongo.replica_set ]]",
        members : []
      };
{{- range $index, $instance := service "[[ .instance ]]-rs[[ .consul.suffix ]]" }}
      rs_conf.members[{{ index $instance.ServiceMeta "alloc" }}] =  {
        _id : {{ index $instance.ServiceMeta "alloc" }},
        host : "{{ index $instance.ServiceMeta "addr" }}:{{ $instance.Port }}"
      };
{{- end }}
      rs.initiate(rs_conf);
_EOF

  echo "Creating root user"
  mongosh \
    --eval << '_EOF'
    db.getSiblingDB("$external").createUser({
      user: "CN=mongo.root,OU=[[ .vault.pki.ou ]]",
      roles: [{ role: "root", db: "admin" }]
    });
_EOF

fi
